// node modules
import React, { FC } from 'react';

// local components
import { Typography } from "../../typography";

// local files
import { palette } from "../../../theme/palette";
import { theming } from "../../../theme";
import { useStyles } from "./styles";

export interface ProgressBarThinProps {
    percents: number;
    title: string;
    color?: string;
    completed?: boolean;
    className?: string;
}

export const ProgressBarThin: FC<ProgressBarThinProps>  = ({
    percents = 0,
    color = palette.primary,
    completed = true,
    title,
    className
}) => {
    const {
        progressWrapper,
        progress,
        infoWrapper, counter
    } = useStyles({ theme: theming.useTheme() });
    const width = `calc(100% * ${percents/100})`;
    const variant = completed ? 'body2' : 'h3';

    return (
        <div className={className}>
            <div className={infoWrapper}>
                <Typography variant={variant} style={{ color }}>{title}</Typography>
                <Typography className={counter} variant={variant} style={{ color }}>{percents} %</Typography>
            </div>
            <div className={progressWrapper}>
                <div
                    className={progress}
                    style={{
                        background: color,
                        width
                    }}
                />
            </div>
        </div>
    )
}
