import { useEffect, useState } from "react";

import { getDefaultValue } from "../functions/get_default_storage_data";
import {LOCAL_STORAGE_EVENT_NAME} from "../../constants/events";

type StorageParams = {
    key: string;
    defaultValue: any;
}

export const useLocalStorage = ({ key, defaultValue }: StorageParams) => {
    const [pageValue, setPageValue] = useState(getDefaultValue(key, defaultValue))

    useEffect(() => {
        window.addEventListener(LOCAL_STORAGE_EVENT_NAME, (e:any) => {
            if(key === e.detail.keyEvent) {
                setPageValue(e.detail.value)
            }
        })

        return () => {
            window.removeEventListener(LOCAL_STORAGE_EVENT_NAME, (e:any) => {
                if(key === e.detail.keyEvent) {
                    setPageValue(e.detail.value)
                }
            })
        }
    }, [key])

    useEffect(() => {
        if (typeof pageValue === 'object') {
            localStorage.setItem(key, JSON.stringify(pageValue) || '')
        } else {
            localStorage.setItem(key, pageValue || '')
        }
        window.dispatchEvent(createUpdateStorageCustomEvent(pageValue, key))
    }, [pageValue, key])

    return {pageValue, setPageValue}
}

function createUpdateStorageCustomEvent(value: any, keyEvent: string) {
    return new CustomEvent(
        LOCAL_STORAGE_EVENT_NAME,
        { detail: { value, keyEvent } }
    )
};